timeintervaltools.calculate_depth_centroid_of_intervals
=======================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_depth_centroid_of_intervals.calculate_depth_centroid_of_intervals
